@@ -4,8 +4,11 @@ import os.path as op
 from argparse      import ArgumentParser
 from bids.grabbids import BIDSLayout
 
-from .      import spm_dep, fourD_rsHRF
-from .rsHRF_GUI import run 
+from rsHRF      import spm_dep, fourD_rsHRF
+
+#to decouple it from the docker version
+try: from .rsHRF_GUI import run 
+except: pass
 
 import warnings
 warnings.filterwarnings("ignore")
@@ -79,6 +82,10 @@ def get_parser():
                             default=[0.01, 0.08],
                             help='set intervals for bandpass filter, default is 0.01 - 0.08')
 
+    group_para.add_argument('--passband_deconvolve', action='store', type=float, nargs=2, metavar=('LOW_FREQ', 'HIGH_FREQ'),
+                            default=[0.0, sys.float_info.max],
+                            help='set intervals for bandpass filter (used while deconvolving BOLD), default is no-filtering')
+
     group_para.add_argument('-TR', action='store', type=float, default=-1,
                             help='set TR parameter')
 
@@ -138,7 +145,10 @@ def run_rsHRF():
 
     if (args.GUI):
         if (nargs == 2):
-            run.run()
+            try:
+                run.run()
+            except:
+                parser.error('--GUI should not be used inside a Docker container')
         else:
             parser.error('--no other arguments should be supplied with --GUI')
 
@@ -354,4 +364,4 @@ def main():
 
 if __name__ == '__main__':
     raise RuntimeError("CLI.py should not be run directly;\n"
-                       "Please `pip install` rsHRF and use the `rsHRF` command")
\ No newline at end of file
+                       "Please `pip install` rsHRF and use the `rsHRF` command")
